from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class RadiationEquivalentDoseRateUnits(Enum):
        """
            RadiationEquivalentDoseRateUnits enumeration
        """
        
        SievertPerHour = 'SievertPerHour'
        """
            
        """
        
        SievertPerSecond = 'SievertPerSecond'
        """
            
        """
        
        RoentgenEquivalentManPerHour = 'RoentgenEquivalentManPerHour'
        """
            
        """
        
        NanosievertPerHour = 'NanosievertPerHour'
        """
            
        """
        
        MicrosievertPerHour = 'MicrosievertPerHour'
        """
            
        """
        
        MillisievertPerHour = 'MillisievertPerHour'
        """
            
        """
        
        NanosievertPerSecond = 'NanosievertPerSecond'
        """
            
        """
        
        MicrosievertPerSecond = 'MicrosievertPerSecond'
        """
            
        """
        
        MillisievertPerSecond = 'MillisievertPerSecond'
        """
            
        """
        
        MilliroentgenEquivalentManPerHour = 'MilliroentgenEquivalentManPerHour'
        """
            
        """
        

class RadiationEquivalentDoseRateDto:
    """
    A DTO representation of a RadiationEquivalentDoseRate

    Attributes:
        value (float): The value of the RadiationEquivalentDoseRate.
        unit (RadiationEquivalentDoseRateUnits): The specific unit that the RadiationEquivalentDoseRate value is representing.
    """

    def __init__(self, value: float, unit: RadiationEquivalentDoseRateUnits):
        """
        Create a new DTO representation of a RadiationEquivalentDoseRate

        Parameters:
            value (float): The value of the RadiationEquivalentDoseRate.
            unit (RadiationEquivalentDoseRateUnits): The specific unit that the RadiationEquivalentDoseRate value is representing.
        """
        self.value: float = value
        """
        The value of the RadiationEquivalentDoseRate
        """
        self.unit: RadiationEquivalentDoseRateUnits = unit
        """
        The specific unit that the RadiationEquivalentDoseRate value is representing
        """

    def to_json(self):
        """
        Get a RadiationEquivalentDoseRate DTO JSON object representing the current unit.

        :return: JSON object represents RadiationEquivalentDoseRate DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "SievertPerSecond"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of RadiationEquivalentDoseRate DTO from a json representation.

        :param data: The RadiationEquivalentDoseRate DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "SievertPerSecond"}
        :return: A new instance of RadiationEquivalentDoseRateDto.
        :rtype: RadiationEquivalentDoseRateDto
        """
        return RadiationEquivalentDoseRateDto(value=data["value"], unit=RadiationEquivalentDoseRateUnits(data["unit"]))


class RadiationEquivalentDoseRate(AbstractMeasure):
    """
    A dose rate is quantity of radiation absorbed or delivered per unit time.

    Args:
        value (float): The value.
        from_unit (RadiationEquivalentDoseRateUnits): The RadiationEquivalentDoseRate unit to create from, The default unit is SievertPerSecond
    """
    def __init__(self, value: float, from_unit: RadiationEquivalentDoseRateUnits = RadiationEquivalentDoseRateUnits.SievertPerSecond):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__sieverts_per_hour = None
        
        self.__sieverts_per_second = None
        
        self.__roentgens_equivalent_man_per_hour = None
        
        self.__nanosieverts_per_hour = None
        
        self.__microsieverts_per_hour = None
        
        self.__millisieverts_per_hour = None
        
        self.__nanosieverts_per_second = None
        
        self.__microsieverts_per_second = None
        
        self.__millisieverts_per_second = None
        
        self.__milliroentgens_equivalent_man_per_hour = None
        

    def convert(self, unit: RadiationEquivalentDoseRateUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: RadiationEquivalentDoseRateUnits = RadiationEquivalentDoseRateUnits.SievertPerSecond) -> RadiationEquivalentDoseRateDto:
        """
        Get a new instance of RadiationEquivalentDoseRate DTO representing the current unit.

        :param hold_in_unit: The specific RadiationEquivalentDoseRate unit to store the RadiationEquivalentDoseRate value in the DTO representation.
        :type hold_in_unit: RadiationEquivalentDoseRateUnits
        :return: A new instance of RadiationEquivalentDoseRateDto.
        :rtype: RadiationEquivalentDoseRateDto
        """
        return RadiationEquivalentDoseRateDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: RadiationEquivalentDoseRateUnits = RadiationEquivalentDoseRateUnits.SievertPerSecond):
        """
        Get a RadiationEquivalentDoseRate DTO JSON object representing the current unit.

        :param hold_in_unit: The specific RadiationEquivalentDoseRate unit to store the RadiationEquivalentDoseRate value in the DTO representation.
        :type hold_in_unit: RadiationEquivalentDoseRateUnits
        :return: JSON object represents RadiationEquivalentDoseRate DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "SievertPerSecond"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(radiation_equivalent_dose_rate_dto: RadiationEquivalentDoseRateDto):
        """
        Obtain a new instance of RadiationEquivalentDoseRate from a DTO unit object.

        :param radiation_equivalent_dose_rate_dto: The RadiationEquivalentDoseRate DTO representation.
        :type radiation_equivalent_dose_rate_dto: RadiationEquivalentDoseRateDto
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(radiation_equivalent_dose_rate_dto.value, radiation_equivalent_dose_rate_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of RadiationEquivalentDoseRate from a DTO unit json representation.

        :param data: The RadiationEquivalentDoseRate DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "SievertPerSecond"}
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate.from_dto(RadiationEquivalentDoseRateDto.from_json(data))

    def __convert_from_base(self, from_unit: RadiationEquivalentDoseRateUnits) -> float:
        value = self._value
        
        if from_unit == RadiationEquivalentDoseRateUnits.SievertPerHour:
            return (value*3600)
        
        if from_unit == RadiationEquivalentDoseRateUnits.SievertPerSecond:
            return (value)
        
        if from_unit == RadiationEquivalentDoseRateUnits.RoentgenEquivalentManPerHour:
            return (value * 100 * 3600)
        
        if from_unit == RadiationEquivalentDoseRateUnits.NanosievertPerHour:
            return ((value*3600) / 1e-09)
        
        if from_unit == RadiationEquivalentDoseRateUnits.MicrosievertPerHour:
            return ((value*3600) / 1e-06)
        
        if from_unit == RadiationEquivalentDoseRateUnits.MillisievertPerHour:
            return ((value*3600) / 0.001)
        
        if from_unit == RadiationEquivalentDoseRateUnits.NanosievertPerSecond:
            return ((value) / 1e-09)
        
        if from_unit == RadiationEquivalentDoseRateUnits.MicrosievertPerSecond:
            return ((value) / 1e-06)
        
        if from_unit == RadiationEquivalentDoseRateUnits.MillisievertPerSecond:
            return ((value) / 0.001)
        
        if from_unit == RadiationEquivalentDoseRateUnits.MilliroentgenEquivalentManPerHour:
            return ((value * 100 * 3600) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: RadiationEquivalentDoseRateUnits) -> float:
        
        if to_unit == RadiationEquivalentDoseRateUnits.SievertPerHour:
            return (value/3600)
        
        if to_unit == RadiationEquivalentDoseRateUnits.SievertPerSecond:
            return (value)
        
        if to_unit == RadiationEquivalentDoseRateUnits.RoentgenEquivalentManPerHour:
            return (value / 100 / 3600)
        
        if to_unit == RadiationEquivalentDoseRateUnits.NanosievertPerHour:
            return ((value/3600) * 1e-09)
        
        if to_unit == RadiationEquivalentDoseRateUnits.MicrosievertPerHour:
            return ((value/3600) * 1e-06)
        
        if to_unit == RadiationEquivalentDoseRateUnits.MillisievertPerHour:
            return ((value/3600) * 0.001)
        
        if to_unit == RadiationEquivalentDoseRateUnits.NanosievertPerSecond:
            return ((value) * 1e-09)
        
        if to_unit == RadiationEquivalentDoseRateUnits.MicrosievertPerSecond:
            return ((value) * 1e-06)
        
        if to_unit == RadiationEquivalentDoseRateUnits.MillisievertPerSecond:
            return ((value) * 0.001)
        
        if to_unit == RadiationEquivalentDoseRateUnits.MilliroentgenEquivalentManPerHour:
            return ((value / 100 / 3600) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_sieverts_per_hour(sieverts_per_hour: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in sieverts_per_hour.

        

        :param meters: The RadiationEquivalentDoseRate value in sieverts_per_hour.
        :type sieverts_per_hour: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(sieverts_per_hour, RadiationEquivalentDoseRateUnits.SievertPerHour)

    
    @staticmethod
    def from_sieverts_per_second(sieverts_per_second: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in sieverts_per_second.

        

        :param meters: The RadiationEquivalentDoseRate value in sieverts_per_second.
        :type sieverts_per_second: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(sieverts_per_second, RadiationEquivalentDoseRateUnits.SievertPerSecond)

    
    @staticmethod
    def from_roentgens_equivalent_man_per_hour(roentgens_equivalent_man_per_hour: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in roentgens_equivalent_man_per_hour.

        

        :param meters: The RadiationEquivalentDoseRate value in roentgens_equivalent_man_per_hour.
        :type roentgens_equivalent_man_per_hour: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(roentgens_equivalent_man_per_hour, RadiationEquivalentDoseRateUnits.RoentgenEquivalentManPerHour)

    
    @staticmethod
    def from_nanosieverts_per_hour(nanosieverts_per_hour: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in nanosieverts_per_hour.

        

        :param meters: The RadiationEquivalentDoseRate value in nanosieverts_per_hour.
        :type nanosieverts_per_hour: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(nanosieverts_per_hour, RadiationEquivalentDoseRateUnits.NanosievertPerHour)

    
    @staticmethod
    def from_microsieverts_per_hour(microsieverts_per_hour: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in microsieverts_per_hour.

        

        :param meters: The RadiationEquivalentDoseRate value in microsieverts_per_hour.
        :type microsieverts_per_hour: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(microsieverts_per_hour, RadiationEquivalentDoseRateUnits.MicrosievertPerHour)

    
    @staticmethod
    def from_millisieverts_per_hour(millisieverts_per_hour: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in millisieverts_per_hour.

        

        :param meters: The RadiationEquivalentDoseRate value in millisieverts_per_hour.
        :type millisieverts_per_hour: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(millisieverts_per_hour, RadiationEquivalentDoseRateUnits.MillisievertPerHour)

    
    @staticmethod
    def from_nanosieverts_per_second(nanosieverts_per_second: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in nanosieverts_per_second.

        

        :param meters: The RadiationEquivalentDoseRate value in nanosieverts_per_second.
        :type nanosieverts_per_second: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(nanosieverts_per_second, RadiationEquivalentDoseRateUnits.NanosievertPerSecond)

    
    @staticmethod
    def from_microsieverts_per_second(microsieverts_per_second: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in microsieverts_per_second.

        

        :param meters: The RadiationEquivalentDoseRate value in microsieverts_per_second.
        :type microsieverts_per_second: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(microsieverts_per_second, RadiationEquivalentDoseRateUnits.MicrosievertPerSecond)

    
    @staticmethod
    def from_millisieverts_per_second(millisieverts_per_second: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in millisieverts_per_second.

        

        :param meters: The RadiationEquivalentDoseRate value in millisieverts_per_second.
        :type millisieverts_per_second: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(millisieverts_per_second, RadiationEquivalentDoseRateUnits.MillisievertPerSecond)

    
    @staticmethod
    def from_milliroentgens_equivalent_man_per_hour(milliroentgens_equivalent_man_per_hour: float):
        """
        Create a new instance of RadiationEquivalentDoseRate from a value in milliroentgens_equivalent_man_per_hour.

        

        :param meters: The RadiationEquivalentDoseRate value in milliroentgens_equivalent_man_per_hour.
        :type milliroentgens_equivalent_man_per_hour: float
        :return: A new instance of RadiationEquivalentDoseRate.
        :rtype: RadiationEquivalentDoseRate
        """
        return RadiationEquivalentDoseRate(milliroentgens_equivalent_man_per_hour, RadiationEquivalentDoseRateUnits.MilliroentgenEquivalentManPerHour)

    
    @property
    def sieverts_per_hour(self) -> float:
        """
        
        """
        if self.__sieverts_per_hour != None:
            return self.__sieverts_per_hour
        self.__sieverts_per_hour = self.__convert_from_base(RadiationEquivalentDoseRateUnits.SievertPerHour)
        return self.__sieverts_per_hour

    
    @property
    def sieverts_per_second(self) -> float:
        """
        
        """
        if self.__sieverts_per_second != None:
            return self.__sieverts_per_second
        self.__sieverts_per_second = self.__convert_from_base(RadiationEquivalentDoseRateUnits.SievertPerSecond)
        return self.__sieverts_per_second

    
    @property
    def roentgens_equivalent_man_per_hour(self) -> float:
        """
        
        """
        if self.__roentgens_equivalent_man_per_hour != None:
            return self.__roentgens_equivalent_man_per_hour
        self.__roentgens_equivalent_man_per_hour = self.__convert_from_base(RadiationEquivalentDoseRateUnits.RoentgenEquivalentManPerHour)
        return self.__roentgens_equivalent_man_per_hour

    
    @property
    def nanosieverts_per_hour(self) -> float:
        """
        
        """
        if self.__nanosieverts_per_hour != None:
            return self.__nanosieverts_per_hour
        self.__nanosieverts_per_hour = self.__convert_from_base(RadiationEquivalentDoseRateUnits.NanosievertPerHour)
        return self.__nanosieverts_per_hour

    
    @property
    def microsieverts_per_hour(self) -> float:
        """
        
        """
        if self.__microsieverts_per_hour != None:
            return self.__microsieverts_per_hour
        self.__microsieverts_per_hour = self.__convert_from_base(RadiationEquivalentDoseRateUnits.MicrosievertPerHour)
        return self.__microsieverts_per_hour

    
    @property
    def millisieverts_per_hour(self) -> float:
        """
        
        """
        if self.__millisieverts_per_hour != None:
            return self.__millisieverts_per_hour
        self.__millisieverts_per_hour = self.__convert_from_base(RadiationEquivalentDoseRateUnits.MillisievertPerHour)
        return self.__millisieverts_per_hour

    
    @property
    def nanosieverts_per_second(self) -> float:
        """
        
        """
        if self.__nanosieverts_per_second != None:
            return self.__nanosieverts_per_second
        self.__nanosieverts_per_second = self.__convert_from_base(RadiationEquivalentDoseRateUnits.NanosievertPerSecond)
        return self.__nanosieverts_per_second

    
    @property
    def microsieverts_per_second(self) -> float:
        """
        
        """
        if self.__microsieverts_per_second != None:
            return self.__microsieverts_per_second
        self.__microsieverts_per_second = self.__convert_from_base(RadiationEquivalentDoseRateUnits.MicrosievertPerSecond)
        return self.__microsieverts_per_second

    
    @property
    def millisieverts_per_second(self) -> float:
        """
        
        """
        if self.__millisieverts_per_second != None:
            return self.__millisieverts_per_second
        self.__millisieverts_per_second = self.__convert_from_base(RadiationEquivalentDoseRateUnits.MillisievertPerSecond)
        return self.__millisieverts_per_second

    
    @property
    def milliroentgens_equivalent_man_per_hour(self) -> float:
        """
        
        """
        if self.__milliroentgens_equivalent_man_per_hour != None:
            return self.__milliroentgens_equivalent_man_per_hour
        self.__milliroentgens_equivalent_man_per_hour = self.__convert_from_base(RadiationEquivalentDoseRateUnits.MilliroentgenEquivalentManPerHour)
        return self.__milliroentgens_equivalent_man_per_hour

    
    def to_string(self, unit: RadiationEquivalentDoseRateUnits = RadiationEquivalentDoseRateUnits.SievertPerSecond, fractional_digits: int = None) -> str:
        """
        Format the RadiationEquivalentDoseRate to a string.
        
        Note: the default format for RadiationEquivalentDoseRate is SievertPerSecond.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the RadiationEquivalentDoseRate. Default is 'SievertPerSecond'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == RadiationEquivalentDoseRateUnits.SievertPerHour:
            return f"""{super()._truncate_fraction_digits(self.sieverts_per_hour, fractional_digits)} Sv/h"""
        
        if unit == RadiationEquivalentDoseRateUnits.SievertPerSecond:
            return f"""{super()._truncate_fraction_digits(self.sieverts_per_second, fractional_digits)} Sv/s"""
        
        if unit == RadiationEquivalentDoseRateUnits.RoentgenEquivalentManPerHour:
            return f"""{super()._truncate_fraction_digits(self.roentgens_equivalent_man_per_hour, fractional_digits)} rem/h"""
        
        if unit == RadiationEquivalentDoseRateUnits.NanosievertPerHour:
            return f"""{super()._truncate_fraction_digits(self.nanosieverts_per_hour, fractional_digits)} nSv/h"""
        
        if unit == RadiationEquivalentDoseRateUnits.MicrosievertPerHour:
            return f"""{super()._truncate_fraction_digits(self.microsieverts_per_hour, fractional_digits)} μSv/h"""
        
        if unit == RadiationEquivalentDoseRateUnits.MillisievertPerHour:
            return f"""{super()._truncate_fraction_digits(self.millisieverts_per_hour, fractional_digits)} mSv/h"""
        
        if unit == RadiationEquivalentDoseRateUnits.NanosievertPerSecond:
            return f"""{super()._truncate_fraction_digits(self.nanosieverts_per_second, fractional_digits)} nSv/s"""
        
        if unit == RadiationEquivalentDoseRateUnits.MicrosievertPerSecond:
            return f"""{super()._truncate_fraction_digits(self.microsieverts_per_second, fractional_digits)} μSv/s"""
        
        if unit == RadiationEquivalentDoseRateUnits.MillisievertPerSecond:
            return f"""{super()._truncate_fraction_digits(self.millisieverts_per_second, fractional_digits)} mSv/s"""
        
        if unit == RadiationEquivalentDoseRateUnits.MilliroentgenEquivalentManPerHour:
            return f"""{super()._truncate_fraction_digits(self.milliroentgens_equivalent_man_per_hour, fractional_digits)} mrem/h"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: RadiationEquivalentDoseRateUnits = RadiationEquivalentDoseRateUnits.SievertPerSecond) -> str:
        """
        Get RadiationEquivalentDoseRate unit abbreviation.
        Note! the default abbreviation for RadiationEquivalentDoseRate is SievertPerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.SievertPerHour:
            return """Sv/h"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.SievertPerSecond:
            return """Sv/s"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.RoentgenEquivalentManPerHour:
            return """rem/h"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.NanosievertPerHour:
            return """nSv/h"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.MicrosievertPerHour:
            return """μSv/h"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.MillisievertPerHour:
            return """mSv/h"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.NanosievertPerSecond:
            return """nSv/s"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.MicrosievertPerSecond:
            return """μSv/s"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.MillisievertPerSecond:
            return """mSv/s"""
        
        if unit_abbreviation == RadiationEquivalentDoseRateUnits.MilliroentgenEquivalentManPerHour:
            return """mrem/h"""
        


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class DoseAreaProductUnits(Enum):
        """
            DoseAreaProductUnits enumeration
        """
        
        GraySquareMeter = 'GraySquareMeter'
        """
            
        """
        
        GraySquareDecimeter = 'GraySquareDecimeter'
        """
            
        """
        
        GraySquareCentimeter = 'GraySquareCentimeter'
        """
            
        """
        
        GraySquareMillimeter = 'GraySquareMillimeter'
        """
            
        """
        
        MicrograySquareMeter = 'MicrograySquareMeter'
        """
            
        """
        
        MilligraySquareMeter = 'MilligraySquareMeter'
        """
            
        """
        
        CentigraySquareMeter = 'CentigraySquareMeter'
        """
            
        """
        
        DecigraySquareMeter = 'DecigraySquareMeter'
        """
            
        """
        
        MicrograySquareDecimeter = 'MicrograySquareDecimeter'
        """
            
        """
        
        MilligraySquareDecimeter = 'MilligraySquareDecimeter'
        """
            
        """
        
        CentigraySquareDecimeter = 'CentigraySquareDecimeter'
        """
            
        """
        
        DecigraySquareDecimeter = 'DecigraySquareDecimeter'
        """
            
        """
        
        MicrograySquareCentimeter = 'MicrograySquareCentimeter'
        """
            
        """
        
        MilligraySquareCentimeter = 'MilligraySquareCentimeter'
        """
            
        """
        
        CentigraySquareCentimeter = 'CentigraySquareCentimeter'
        """
            
        """
        
        DecigraySquareCentimeter = 'DecigraySquareCentimeter'
        """
            
        """
        
        MicrograySquareMillimeter = 'MicrograySquareMillimeter'
        """
            
        """
        
        MilligraySquareMillimeter = 'MilligraySquareMillimeter'
        """
            
        """
        
        CentigraySquareMillimeter = 'CentigraySquareMillimeter'
        """
            
        """
        
        DecigraySquareMillimeter = 'DecigraySquareMillimeter'
        """
            
        """
        

class DoseAreaProductDto:
    """
    A DTO representation of a DoseAreaProduct

    Attributes:
        value (float): The value of the DoseAreaProduct.
        unit (DoseAreaProductUnits): The specific unit that the DoseAreaProduct value is representing.
    """

    def __init__(self, value: float, unit: DoseAreaProductUnits):
        """
        Create a new DTO representation of a DoseAreaProduct

        Parameters:
            value (float): The value of the DoseAreaProduct.
            unit (DoseAreaProductUnits): The specific unit that the DoseAreaProduct value is representing.
        """
        self.value: float = value
        """
        The value of the DoseAreaProduct
        """
        self.unit: DoseAreaProductUnits = unit
        """
        The specific unit that the DoseAreaProduct value is representing
        """

    def to_json(self):
        """
        Get a DoseAreaProduct DTO JSON object representing the current unit.

        :return: JSON object represents DoseAreaProduct DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "GraySquareMeter"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of DoseAreaProduct DTO from a json representation.

        :param data: The DoseAreaProduct DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "GraySquareMeter"}
        :return: A new instance of DoseAreaProductDto.
        :rtype: DoseAreaProductDto
        """
        return DoseAreaProductDto(value=data["value"], unit=DoseAreaProductUnits(data["unit"]))


class DoseAreaProduct(AbstractMeasure):
    """
    It is defined as the absorbed dose multiplied by the area irradiated.

    Args:
        value (float): The value.
        from_unit (DoseAreaProductUnits): The DoseAreaProduct unit to create from, The default unit is GraySquareMeter
    """
    def __init__(self, value: float, from_unit: DoseAreaProductUnits = DoseAreaProductUnits.GraySquareMeter):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__gray_square_meters = None
        
        self.__gray_square_decimeters = None
        
        self.__gray_square_centimeters = None
        
        self.__gray_square_millimeters = None
        
        self.__microgray_square_meters = None
        
        self.__milligray_square_meters = None
        
        self.__centigray_square_meters = None
        
        self.__decigray_square_meters = None
        
        self.__microgray_square_decimeters = None
        
        self.__milligray_square_decimeters = None
        
        self.__centigray_square_decimeters = None
        
        self.__decigray_square_decimeters = None
        
        self.__microgray_square_centimeters = None
        
        self.__milligray_square_centimeters = None
        
        self.__centigray_square_centimeters = None
        
        self.__decigray_square_centimeters = None
        
        self.__microgray_square_millimeters = None
        
        self.__milligray_square_millimeters = None
        
        self.__centigray_square_millimeters = None
        
        self.__decigray_square_millimeters = None
        

    def convert(self, unit: DoseAreaProductUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: DoseAreaProductUnits = DoseAreaProductUnits.GraySquareMeter) -> DoseAreaProductDto:
        """
        Get a new instance of DoseAreaProduct DTO representing the current unit.

        :param hold_in_unit: The specific DoseAreaProduct unit to store the DoseAreaProduct value in the DTO representation.
        :type hold_in_unit: DoseAreaProductUnits
        :return: A new instance of DoseAreaProductDto.
        :rtype: DoseAreaProductDto
        """
        return DoseAreaProductDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: DoseAreaProductUnits = DoseAreaProductUnits.GraySquareMeter):
        """
        Get a DoseAreaProduct DTO JSON object representing the current unit.

        :param hold_in_unit: The specific DoseAreaProduct unit to store the DoseAreaProduct value in the DTO representation.
        :type hold_in_unit: DoseAreaProductUnits
        :return: JSON object represents DoseAreaProduct DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "GraySquareMeter"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(dose_area_product_dto: DoseAreaProductDto):
        """
        Obtain a new instance of DoseAreaProduct from a DTO unit object.

        :param dose_area_product_dto: The DoseAreaProduct DTO representation.
        :type dose_area_product_dto: DoseAreaProductDto
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(dose_area_product_dto.value, dose_area_product_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of DoseAreaProduct from a DTO unit json representation.

        :param data: The DoseAreaProduct DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "GraySquareMeter"}
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct.from_dto(DoseAreaProductDto.from_json(data))

    def __convert_from_base(self, from_unit: DoseAreaProductUnits) -> float:
        value = self._value
        
        if from_unit == DoseAreaProductUnits.GraySquareMeter:
            return (value)
        
        if from_unit == DoseAreaProductUnits.GraySquareDecimeter:
            return (value * 100)
        
        if from_unit == DoseAreaProductUnits.GraySquareCentimeter:
            return (value * 10000)
        
        if from_unit == DoseAreaProductUnits.GraySquareMillimeter:
            return (value * 1000000)
        
        if from_unit == DoseAreaProductUnits.MicrograySquareMeter:
            return ((value) / 1e-06)
        
        if from_unit == DoseAreaProductUnits.MilligraySquareMeter:
            return ((value) / 0.001)
        
        if from_unit == DoseAreaProductUnits.CentigraySquareMeter:
            return ((value) / 0.01)
        
        if from_unit == DoseAreaProductUnits.DecigraySquareMeter:
            return ((value) / 0.1)
        
        if from_unit == DoseAreaProductUnits.MicrograySquareDecimeter:
            return ((value * 100) / 1e-06)
        
        if from_unit == DoseAreaProductUnits.MilligraySquareDecimeter:
            return ((value * 100) / 0.001)
        
        if from_unit == DoseAreaProductUnits.CentigraySquareDecimeter:
            return ((value * 100) / 0.01)
        
        if from_unit == DoseAreaProductUnits.DecigraySquareDecimeter:
            return ((value * 100) / 0.1)
        
        if from_unit == DoseAreaProductUnits.MicrograySquareCentimeter:
            return ((value * 10000) / 1e-06)
        
        if from_unit == DoseAreaProductUnits.MilligraySquareCentimeter:
            return ((value * 10000) / 0.001)
        
        if from_unit == DoseAreaProductUnits.CentigraySquareCentimeter:
            return ((value * 10000) / 0.01)
        
        if from_unit == DoseAreaProductUnits.DecigraySquareCentimeter:
            return ((value * 10000) / 0.1)
        
        if from_unit == DoseAreaProductUnits.MicrograySquareMillimeter:
            return ((value * 1000000) / 1e-06)
        
        if from_unit == DoseAreaProductUnits.MilligraySquareMillimeter:
            return ((value * 1000000) / 0.001)
        
        if from_unit == DoseAreaProductUnits.CentigraySquareMillimeter:
            return ((value * 1000000) / 0.01)
        
        if from_unit == DoseAreaProductUnits.DecigraySquareMillimeter:
            return ((value * 1000000) / 0.1)
        
        return None


    def __convert_to_base(self, value: float, to_unit: DoseAreaProductUnits) -> float:
        
        if to_unit == DoseAreaProductUnits.GraySquareMeter:
            return (value)
        
        if to_unit == DoseAreaProductUnits.GraySquareDecimeter:
            return (value / 100)
        
        if to_unit == DoseAreaProductUnits.GraySquareCentimeter:
            return (value / 10000)
        
        if to_unit == DoseAreaProductUnits.GraySquareMillimeter:
            return (value / 1000000)
        
        if to_unit == DoseAreaProductUnits.MicrograySquareMeter:
            return ((value) * 1e-06)
        
        if to_unit == DoseAreaProductUnits.MilligraySquareMeter:
            return ((value) * 0.001)
        
        if to_unit == DoseAreaProductUnits.CentigraySquareMeter:
            return ((value) * 0.01)
        
        if to_unit == DoseAreaProductUnits.DecigraySquareMeter:
            return ((value) * 0.1)
        
        if to_unit == DoseAreaProductUnits.MicrograySquareDecimeter:
            return ((value / 100) * 1e-06)
        
        if to_unit == DoseAreaProductUnits.MilligraySquareDecimeter:
            return ((value / 100) * 0.001)
        
        if to_unit == DoseAreaProductUnits.CentigraySquareDecimeter:
            return ((value / 100) * 0.01)
        
        if to_unit == DoseAreaProductUnits.DecigraySquareDecimeter:
            return ((value / 100) * 0.1)
        
        if to_unit == DoseAreaProductUnits.MicrograySquareCentimeter:
            return ((value / 10000) * 1e-06)
        
        if to_unit == DoseAreaProductUnits.MilligraySquareCentimeter:
            return ((value / 10000) * 0.001)
        
        if to_unit == DoseAreaProductUnits.CentigraySquareCentimeter:
            return ((value / 10000) * 0.01)
        
        if to_unit == DoseAreaProductUnits.DecigraySquareCentimeter:
            return ((value / 10000) * 0.1)
        
        if to_unit == DoseAreaProductUnits.MicrograySquareMillimeter:
            return ((value / 1000000) * 1e-06)
        
        if to_unit == DoseAreaProductUnits.MilligraySquareMillimeter:
            return ((value / 1000000) * 0.001)
        
        if to_unit == DoseAreaProductUnits.CentigraySquareMillimeter:
            return ((value / 1000000) * 0.01)
        
        if to_unit == DoseAreaProductUnits.DecigraySquareMillimeter:
            return ((value / 1000000) * 0.1)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_gray_square_meters(gray_square_meters: float):
        """
        Create a new instance of DoseAreaProduct from a value in gray_square_meters.

        

        :param meters: The DoseAreaProduct value in gray_square_meters.
        :type gray_square_meters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(gray_square_meters, DoseAreaProductUnits.GraySquareMeter)

    
    @staticmethod
    def from_gray_square_decimeters(gray_square_decimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in gray_square_decimeters.

        

        :param meters: The DoseAreaProduct value in gray_square_decimeters.
        :type gray_square_decimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(gray_square_decimeters, DoseAreaProductUnits.GraySquareDecimeter)

    
    @staticmethod
    def from_gray_square_centimeters(gray_square_centimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in gray_square_centimeters.

        

        :param meters: The DoseAreaProduct value in gray_square_centimeters.
        :type gray_square_centimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(gray_square_centimeters, DoseAreaProductUnits.GraySquareCentimeter)

    
    @staticmethod
    def from_gray_square_millimeters(gray_square_millimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in gray_square_millimeters.

        

        :param meters: The DoseAreaProduct value in gray_square_millimeters.
        :type gray_square_millimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(gray_square_millimeters, DoseAreaProductUnits.GraySquareMillimeter)

    
    @staticmethod
    def from_microgray_square_meters(microgray_square_meters: float):
        """
        Create a new instance of DoseAreaProduct from a value in microgray_square_meters.

        

        :param meters: The DoseAreaProduct value in microgray_square_meters.
        :type microgray_square_meters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(microgray_square_meters, DoseAreaProductUnits.MicrograySquareMeter)

    
    @staticmethod
    def from_milligray_square_meters(milligray_square_meters: float):
        """
        Create a new instance of DoseAreaProduct from a value in milligray_square_meters.

        

        :param meters: The DoseAreaProduct value in milligray_square_meters.
        :type milligray_square_meters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(milligray_square_meters, DoseAreaProductUnits.MilligraySquareMeter)

    
    @staticmethod
    def from_centigray_square_meters(centigray_square_meters: float):
        """
        Create a new instance of DoseAreaProduct from a value in centigray_square_meters.

        

        :param meters: The DoseAreaProduct value in centigray_square_meters.
        :type centigray_square_meters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(centigray_square_meters, DoseAreaProductUnits.CentigraySquareMeter)

    
    @staticmethod
    def from_decigray_square_meters(decigray_square_meters: float):
        """
        Create a new instance of DoseAreaProduct from a value in decigray_square_meters.

        

        :param meters: The DoseAreaProduct value in decigray_square_meters.
        :type decigray_square_meters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(decigray_square_meters, DoseAreaProductUnits.DecigraySquareMeter)

    
    @staticmethod
    def from_microgray_square_decimeters(microgray_square_decimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in microgray_square_decimeters.

        

        :param meters: The DoseAreaProduct value in microgray_square_decimeters.
        :type microgray_square_decimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(microgray_square_decimeters, DoseAreaProductUnits.MicrograySquareDecimeter)

    
    @staticmethod
    def from_milligray_square_decimeters(milligray_square_decimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in milligray_square_decimeters.

        

        :param meters: The DoseAreaProduct value in milligray_square_decimeters.
        :type milligray_square_decimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(milligray_square_decimeters, DoseAreaProductUnits.MilligraySquareDecimeter)

    
    @staticmethod
    def from_centigray_square_decimeters(centigray_square_decimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in centigray_square_decimeters.

        

        :param meters: The DoseAreaProduct value in centigray_square_decimeters.
        :type centigray_square_decimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(centigray_square_decimeters, DoseAreaProductUnits.CentigraySquareDecimeter)

    
    @staticmethod
    def from_decigray_square_decimeters(decigray_square_decimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in decigray_square_decimeters.

        

        :param meters: The DoseAreaProduct value in decigray_square_decimeters.
        :type decigray_square_decimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(decigray_square_decimeters, DoseAreaProductUnits.DecigraySquareDecimeter)

    
    @staticmethod
    def from_microgray_square_centimeters(microgray_square_centimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in microgray_square_centimeters.

        

        :param meters: The DoseAreaProduct value in microgray_square_centimeters.
        :type microgray_square_centimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(microgray_square_centimeters, DoseAreaProductUnits.MicrograySquareCentimeter)

    
    @staticmethod
    def from_milligray_square_centimeters(milligray_square_centimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in milligray_square_centimeters.

        

        :param meters: The DoseAreaProduct value in milligray_square_centimeters.
        :type milligray_square_centimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(milligray_square_centimeters, DoseAreaProductUnits.MilligraySquareCentimeter)

    
    @staticmethod
    def from_centigray_square_centimeters(centigray_square_centimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in centigray_square_centimeters.

        

        :param meters: The DoseAreaProduct value in centigray_square_centimeters.
        :type centigray_square_centimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(centigray_square_centimeters, DoseAreaProductUnits.CentigraySquareCentimeter)

    
    @staticmethod
    def from_decigray_square_centimeters(decigray_square_centimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in decigray_square_centimeters.

        

        :param meters: The DoseAreaProduct value in decigray_square_centimeters.
        :type decigray_square_centimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(decigray_square_centimeters, DoseAreaProductUnits.DecigraySquareCentimeter)

    
    @staticmethod
    def from_microgray_square_millimeters(microgray_square_millimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in microgray_square_millimeters.

        

        :param meters: The DoseAreaProduct value in microgray_square_millimeters.
        :type microgray_square_millimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(microgray_square_millimeters, DoseAreaProductUnits.MicrograySquareMillimeter)

    
    @staticmethod
    def from_milligray_square_millimeters(milligray_square_millimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in milligray_square_millimeters.

        

        :param meters: The DoseAreaProduct value in milligray_square_millimeters.
        :type milligray_square_millimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(milligray_square_millimeters, DoseAreaProductUnits.MilligraySquareMillimeter)

    
    @staticmethod
    def from_centigray_square_millimeters(centigray_square_millimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in centigray_square_millimeters.

        

        :param meters: The DoseAreaProduct value in centigray_square_millimeters.
        :type centigray_square_millimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(centigray_square_millimeters, DoseAreaProductUnits.CentigraySquareMillimeter)

    
    @staticmethod
    def from_decigray_square_millimeters(decigray_square_millimeters: float):
        """
        Create a new instance of DoseAreaProduct from a value in decigray_square_millimeters.

        

        :param meters: The DoseAreaProduct value in decigray_square_millimeters.
        :type decigray_square_millimeters: float
        :return: A new instance of DoseAreaProduct.
        :rtype: DoseAreaProduct
        """
        return DoseAreaProduct(decigray_square_millimeters, DoseAreaProductUnits.DecigraySquareMillimeter)

    
    @property
    def gray_square_meters(self) -> float:
        """
        
        """
        if self.__gray_square_meters != None:
            return self.__gray_square_meters
        self.__gray_square_meters = self.__convert_from_base(DoseAreaProductUnits.GraySquareMeter)
        return self.__gray_square_meters

    
    @property
    def gray_square_decimeters(self) -> float:
        """
        
        """
        if self.__gray_square_decimeters != None:
            return self.__gray_square_decimeters
        self.__gray_square_decimeters = self.__convert_from_base(DoseAreaProductUnits.GraySquareDecimeter)
        return self.__gray_square_decimeters

    
    @property
    def gray_square_centimeters(self) -> float:
        """
        
        """
        if self.__gray_square_centimeters != None:
            return self.__gray_square_centimeters
        self.__gray_square_centimeters = self.__convert_from_base(DoseAreaProductUnits.GraySquareCentimeter)
        return self.__gray_square_centimeters

    
    @property
    def gray_square_millimeters(self) -> float:
        """
        
        """
        if self.__gray_square_millimeters != None:
            return self.__gray_square_millimeters
        self.__gray_square_millimeters = self.__convert_from_base(DoseAreaProductUnits.GraySquareMillimeter)
        return self.__gray_square_millimeters

    
    @property
    def microgray_square_meters(self) -> float:
        """
        
        """
        if self.__microgray_square_meters != None:
            return self.__microgray_square_meters
        self.__microgray_square_meters = self.__convert_from_base(DoseAreaProductUnits.MicrograySquareMeter)
        return self.__microgray_square_meters

    
    @property
    def milligray_square_meters(self) -> float:
        """
        
        """
        if self.__milligray_square_meters != None:
            return self.__milligray_square_meters
        self.__milligray_square_meters = self.__convert_from_base(DoseAreaProductUnits.MilligraySquareMeter)
        return self.__milligray_square_meters

    
    @property
    def centigray_square_meters(self) -> float:
        """
        
        """
        if self.__centigray_square_meters != None:
            return self.__centigray_square_meters
        self.__centigray_square_meters = self.__convert_from_base(DoseAreaProductUnits.CentigraySquareMeter)
        return self.__centigray_square_meters

    
    @property
    def decigray_square_meters(self) -> float:
        """
        
        """
        if self.__decigray_square_meters != None:
            return self.__decigray_square_meters
        self.__decigray_square_meters = self.__convert_from_base(DoseAreaProductUnits.DecigraySquareMeter)
        return self.__decigray_square_meters

    
    @property
    def microgray_square_decimeters(self) -> float:
        """
        
        """
        if self.__microgray_square_decimeters != None:
            return self.__microgray_square_decimeters
        self.__microgray_square_decimeters = self.__convert_from_base(DoseAreaProductUnits.MicrograySquareDecimeter)
        return self.__microgray_square_decimeters

    
    @property
    def milligray_square_decimeters(self) -> float:
        """
        
        """
        if self.__milligray_square_decimeters != None:
            return self.__milligray_square_decimeters
        self.__milligray_square_decimeters = self.__convert_from_base(DoseAreaProductUnits.MilligraySquareDecimeter)
        return self.__milligray_square_decimeters

    
    @property
    def centigray_square_decimeters(self) -> float:
        """
        
        """
        if self.__centigray_square_decimeters != None:
            return self.__centigray_square_decimeters
        self.__centigray_square_decimeters = self.__convert_from_base(DoseAreaProductUnits.CentigraySquareDecimeter)
        return self.__centigray_square_decimeters

    
    @property
    def decigray_square_decimeters(self) -> float:
        """
        
        """
        if self.__decigray_square_decimeters != None:
            return self.__decigray_square_decimeters
        self.__decigray_square_decimeters = self.__convert_from_base(DoseAreaProductUnits.DecigraySquareDecimeter)
        return self.__decigray_square_decimeters

    
    @property
    def microgray_square_centimeters(self) -> float:
        """
        
        """
        if self.__microgray_square_centimeters != None:
            return self.__microgray_square_centimeters
        self.__microgray_square_centimeters = self.__convert_from_base(DoseAreaProductUnits.MicrograySquareCentimeter)
        return self.__microgray_square_centimeters

    
    @property
    def milligray_square_centimeters(self) -> float:
        """
        
        """
        if self.__milligray_square_centimeters != None:
            return self.__milligray_square_centimeters
        self.__milligray_square_centimeters = self.__convert_from_base(DoseAreaProductUnits.MilligraySquareCentimeter)
        return self.__milligray_square_centimeters

    
    @property
    def centigray_square_centimeters(self) -> float:
        """
        
        """
        if self.__centigray_square_centimeters != None:
            return self.__centigray_square_centimeters
        self.__centigray_square_centimeters = self.__convert_from_base(DoseAreaProductUnits.CentigraySquareCentimeter)
        return self.__centigray_square_centimeters

    
    @property
    def decigray_square_centimeters(self) -> float:
        """
        
        """
        if self.__decigray_square_centimeters != None:
            return self.__decigray_square_centimeters
        self.__decigray_square_centimeters = self.__convert_from_base(DoseAreaProductUnits.DecigraySquareCentimeter)
        return self.__decigray_square_centimeters

    
    @property
    def microgray_square_millimeters(self) -> float:
        """
        
        """
        if self.__microgray_square_millimeters != None:
            return self.__microgray_square_millimeters
        self.__microgray_square_millimeters = self.__convert_from_base(DoseAreaProductUnits.MicrograySquareMillimeter)
        return self.__microgray_square_millimeters

    
    @property
    def milligray_square_millimeters(self) -> float:
        """
        
        """
        if self.__milligray_square_millimeters != None:
            return self.__milligray_square_millimeters
        self.__milligray_square_millimeters = self.__convert_from_base(DoseAreaProductUnits.MilligraySquareMillimeter)
        return self.__milligray_square_millimeters

    
    @property
    def centigray_square_millimeters(self) -> float:
        """
        
        """
        if self.__centigray_square_millimeters != None:
            return self.__centigray_square_millimeters
        self.__centigray_square_millimeters = self.__convert_from_base(DoseAreaProductUnits.CentigraySquareMillimeter)
        return self.__centigray_square_millimeters

    
    @property
    def decigray_square_millimeters(self) -> float:
        """
        
        """
        if self.__decigray_square_millimeters != None:
            return self.__decigray_square_millimeters
        self.__decigray_square_millimeters = self.__convert_from_base(DoseAreaProductUnits.DecigraySquareMillimeter)
        return self.__decigray_square_millimeters

    
    def to_string(self, unit: DoseAreaProductUnits = DoseAreaProductUnits.GraySquareMeter, fractional_digits: int = None) -> str:
        """
        Format the DoseAreaProduct to a string.
        
        Note: the default format for DoseAreaProduct is GraySquareMeter.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the DoseAreaProduct. Default is 'GraySquareMeter'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == DoseAreaProductUnits.GraySquareMeter:
            return f"""{super()._truncate_fraction_digits(self.gray_square_meters, fractional_digits)} Gy·m²"""
        
        if unit == DoseAreaProductUnits.GraySquareDecimeter:
            return f"""{super()._truncate_fraction_digits(self.gray_square_decimeters, fractional_digits)} Gy·dm²"""
        
        if unit == DoseAreaProductUnits.GraySquareCentimeter:
            return f"""{super()._truncate_fraction_digits(self.gray_square_centimeters, fractional_digits)} Gy·cm²"""
        
        if unit == DoseAreaProductUnits.GraySquareMillimeter:
            return f"""{super()._truncate_fraction_digits(self.gray_square_millimeters, fractional_digits)} Gy·mm²"""
        
        if unit == DoseAreaProductUnits.MicrograySquareMeter:
            return f"""{super()._truncate_fraction_digits(self.microgray_square_meters, fractional_digits)} μGy·m²"""
        
        if unit == DoseAreaProductUnits.MilligraySquareMeter:
            return f"""{super()._truncate_fraction_digits(self.milligray_square_meters, fractional_digits)} mGy·m²"""
        
        if unit == DoseAreaProductUnits.CentigraySquareMeter:
            return f"""{super()._truncate_fraction_digits(self.centigray_square_meters, fractional_digits)} cGy·m²"""
        
        if unit == DoseAreaProductUnits.DecigraySquareMeter:
            return f"""{super()._truncate_fraction_digits(self.decigray_square_meters, fractional_digits)} dGy·m²"""
        
        if unit == DoseAreaProductUnits.MicrograySquareDecimeter:
            return f"""{super()._truncate_fraction_digits(self.microgray_square_decimeters, fractional_digits)} μGy·dm²"""
        
        if unit == DoseAreaProductUnits.MilligraySquareDecimeter:
            return f"""{super()._truncate_fraction_digits(self.milligray_square_decimeters, fractional_digits)} mGy·dm²"""
        
        if unit == DoseAreaProductUnits.CentigraySquareDecimeter:
            return f"""{super()._truncate_fraction_digits(self.centigray_square_decimeters, fractional_digits)} cGy·dm²"""
        
        if unit == DoseAreaProductUnits.DecigraySquareDecimeter:
            return f"""{super()._truncate_fraction_digits(self.decigray_square_decimeters, fractional_digits)} dGy·dm²"""
        
        if unit == DoseAreaProductUnits.MicrograySquareCentimeter:
            return f"""{super()._truncate_fraction_digits(self.microgray_square_centimeters, fractional_digits)} μGy·cm²"""
        
        if unit == DoseAreaProductUnits.MilligraySquareCentimeter:
            return f"""{super()._truncate_fraction_digits(self.milligray_square_centimeters, fractional_digits)} mGy·cm²"""
        
        if unit == DoseAreaProductUnits.CentigraySquareCentimeter:
            return f"""{super()._truncate_fraction_digits(self.centigray_square_centimeters, fractional_digits)} cGy·cm²"""
        
        if unit == DoseAreaProductUnits.DecigraySquareCentimeter:
            return f"""{super()._truncate_fraction_digits(self.decigray_square_centimeters, fractional_digits)} dGy·cm²"""
        
        if unit == DoseAreaProductUnits.MicrograySquareMillimeter:
            return f"""{super()._truncate_fraction_digits(self.microgray_square_millimeters, fractional_digits)} μGy·mm²"""
        
        if unit == DoseAreaProductUnits.MilligraySquareMillimeter:
            return f"""{super()._truncate_fraction_digits(self.milligray_square_millimeters, fractional_digits)} mGy·mm²"""
        
        if unit == DoseAreaProductUnits.CentigraySquareMillimeter:
            return f"""{super()._truncate_fraction_digits(self.centigray_square_millimeters, fractional_digits)} cGy·mm²"""
        
        if unit == DoseAreaProductUnits.DecigraySquareMillimeter:
            return f"""{super()._truncate_fraction_digits(self.decigray_square_millimeters, fractional_digits)} dGy·mm²"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: DoseAreaProductUnits = DoseAreaProductUnits.GraySquareMeter) -> str:
        """
        Get DoseAreaProduct unit abbreviation.
        Note! the default abbreviation for DoseAreaProduct is GraySquareMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == DoseAreaProductUnits.GraySquareMeter:
            return """Gy·m²"""
        
        if unit_abbreviation == DoseAreaProductUnits.GraySquareDecimeter:
            return """Gy·dm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.GraySquareCentimeter:
            return """Gy·cm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.GraySquareMillimeter:
            return """Gy·mm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MicrograySquareMeter:
            return """μGy·m²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MilligraySquareMeter:
            return """mGy·m²"""
        
        if unit_abbreviation == DoseAreaProductUnits.CentigraySquareMeter:
            return """cGy·m²"""
        
        if unit_abbreviation == DoseAreaProductUnits.DecigraySquareMeter:
            return """dGy·m²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MicrograySquareDecimeter:
            return """μGy·dm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MilligraySquareDecimeter:
            return """mGy·dm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.CentigraySquareDecimeter:
            return """cGy·dm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.DecigraySquareDecimeter:
            return """dGy·dm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MicrograySquareCentimeter:
            return """μGy·cm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MilligraySquareCentimeter:
            return """mGy·cm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.CentigraySquareCentimeter:
            return """cGy·cm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.DecigraySquareCentimeter:
            return """dGy·cm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MicrograySquareMillimeter:
            return """μGy·mm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.MilligraySquareMillimeter:
            return """mGy·mm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.CentigraySquareMillimeter:
            return """cGy·mm²"""
        
        if unit_abbreviation == DoseAreaProductUnits.DecigraySquareMillimeter:
            return """dGy·mm²"""
        


# -*- coding: utf-8 -*-
from setuptools import setup
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding='utf-8')

packages = [
    'unitsnet_py',
    'unitsnet_py.units'
]

package_data = {
    '': ['*']
}

# The UnitNet definition version that the current package is based on to generate units classes
# see 
definition_version = '5.65.0'

setup_kwargs = {
    'name': 'unitsnet-py',
    'version': '0.1.140',
    'license': 'MIT',
    'keywords': 'conversion, units-of-measure, units, quantities, unit-converter, converter, unit, measure, measures, measurement, measurements',
    'description': 'A better way to hold unit variables and easily convert to the destination unit',
    'long_description': long_description,
    'long_description_content_type': "text/markdown",
    'author': 'Haim Kastner',
    'author_email': 'hello@haim-kastner.com',
    'maintainer': 'Haim Kastner',
    'maintainer_email': 'hello@haim-kastner.com',
    'url': 'https://github.com/haimkastner/unitsnet-py',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
    'install_requires': [],
    'classifiers': [
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
     ],
    'project_urls': {
        'Source': 'https://github.com/haimkastner/unitsnet-py',
        'Documentation': 'https://github.com/haimkastner/unitsnet-py#readme',
        'Issue Tracker': 'https://github.com/haimkastner/unitsnet-py/issues',
    },
}

setup(**setup_kwargs)



from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class ElectricApparentPowerUnits(Enum):
        """
            ElectricApparentPowerUnits enumeration
        """
        
        Voltampere = 'Voltampere'
        """
            
        """
        
        Microvoltampere = 'Microvoltampere'
        """
            
        """
        
        Millivoltampere = 'Millivoltampere'
        """
            
        """
        
        Kilovoltampere = 'Kilovoltampere'
        """
            
        """
        
        Megavoltampere = 'Megavoltampere'
        """
            
        """
        
        Gigavoltampere = 'Gigavoltampere'
        """
            
        """
        

class ElectricApparentPowerDto:
    """
    A DTO representation of a ElectricApparentPower

    Attributes:
        value (float): The value of the ElectricApparentPower.
        unit (ElectricApparentPowerUnits): The specific unit that the ElectricApparentPower value is representing.
    """

    def __init__(self, value: float, unit: ElectricApparentPowerUnits):
        """
        Create a new DTO representation of a ElectricApparentPower

        Parameters:
            value (float): The value of the ElectricApparentPower.
            unit (ElectricApparentPowerUnits): The specific unit that the ElectricApparentPower value is representing.
        """
        self.value: float = value
        """
        The value of the ElectricApparentPower
        """
        self.unit: ElectricApparentPowerUnits = unit
        """
        The specific unit that the ElectricApparentPower value is representing
        """

    def to_json(self):
        """
        Get a ElectricApparentPower DTO JSON object representing the current unit.

        :return: JSON object represents ElectricApparentPower DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "Voltampere"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of ElectricApparentPower DTO from a json representation.

        :param data: The ElectricApparentPower DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "Voltampere"}
        :return: A new instance of ElectricApparentPowerDto.
        :rtype: ElectricApparentPowerDto
        """
        return ElectricApparentPowerDto(value=data["value"], unit=ElectricApparentPowerUnits(data["unit"]))


class ElectricApparentPower(AbstractMeasure):
    """
    Power engineers measure apparent power as the magnitude of the vector sum of active and reactive power. It is the product of the root mean square voltage (in volts) and the root mean square current (in amperes).

    Args:
        value (float): The value.
        from_unit (ElectricApparentPowerUnits): The ElectricApparentPower unit to create from, The default unit is Voltampere
    """
    def __init__(self, value: float, from_unit: ElectricApparentPowerUnits = ElectricApparentPowerUnits.Voltampere):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__voltamperes = None
        
        self.__microvoltamperes = None
        
        self.__millivoltamperes = None
        
        self.__kilovoltamperes = None
        
        self.__megavoltamperes = None
        
        self.__gigavoltamperes = None
        

    def convert(self, unit: ElectricApparentPowerUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: ElectricApparentPowerUnits = ElectricApparentPowerUnits.Voltampere) -> ElectricApparentPowerDto:
        """
        Get a new instance of ElectricApparentPower DTO representing the current unit.

        :param hold_in_unit: The specific ElectricApparentPower unit to store the ElectricApparentPower value in the DTO representation.
        :type hold_in_unit: ElectricApparentPowerUnits
        :return: A new instance of ElectricApparentPowerDto.
        :rtype: ElectricApparentPowerDto
        """
        return ElectricApparentPowerDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: ElectricApparentPowerUnits = ElectricApparentPowerUnits.Voltampere):
        """
        Get a ElectricApparentPower DTO JSON object representing the current unit.

        :param hold_in_unit: The specific ElectricApparentPower unit to store the ElectricApparentPower value in the DTO representation.
        :type hold_in_unit: ElectricApparentPowerUnits
        :return: JSON object represents ElectricApparentPower DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "Voltampere"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(electric_apparent_power_dto: ElectricApparentPowerDto):
        """
        Obtain a new instance of ElectricApparentPower from a DTO unit object.

        :param electric_apparent_power_dto: The ElectricApparentPower DTO representation.
        :type electric_apparent_power_dto: ElectricApparentPowerDto
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower(electric_apparent_power_dto.value, electric_apparent_power_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of ElectricApparentPower from a DTO unit json representation.

        :param data: The ElectricApparentPower DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "Voltampere"}
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower.from_dto(ElectricApparentPowerDto.from_json(data))

    def __convert_from_base(self, from_unit: ElectricApparentPowerUnits) -> float:
        value = self._value
        
        if from_unit == ElectricApparentPowerUnits.Voltampere:
            return (value)
        
        if from_unit == ElectricApparentPowerUnits.Microvoltampere:
            return ((value) / 1e-06)
        
        if from_unit == ElectricApparentPowerUnits.Millivoltampere:
            return ((value) / 0.001)
        
        if from_unit == ElectricApparentPowerUnits.Kilovoltampere:
            return ((value) / 1000.0)
        
        if from_unit == ElectricApparentPowerUnits.Megavoltampere:
            return ((value) / 1000000.0)
        
        if from_unit == ElectricApparentPowerUnits.Gigavoltampere:
            return ((value) / 1000000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricApparentPowerUnits) -> float:
        
        if to_unit == ElectricApparentPowerUnits.Voltampere:
            return (value)
        
        if to_unit == ElectricApparentPowerUnits.Microvoltampere:
            return ((value) * 1e-06)
        
        if to_unit == ElectricApparentPowerUnits.Millivoltampere:
            return ((value) * 0.001)
        
        if to_unit == ElectricApparentPowerUnits.Kilovoltampere:
            return ((value) * 1000.0)
        
        if to_unit == ElectricApparentPowerUnits.Megavoltampere:
            return ((value) * 1000000.0)
        
        if to_unit == ElectricApparentPowerUnits.Gigavoltampere:
            return ((value) * 1000000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_voltamperes(voltamperes: float):
        """
        Create a new instance of ElectricApparentPower from a value in voltamperes.

        

        :param meters: The ElectricApparentPower value in voltamperes.
        :type voltamperes: float
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower(voltamperes, ElectricApparentPowerUnits.Voltampere)

    
    @staticmethod
    def from_microvoltamperes(microvoltamperes: float):
        """
        Create a new instance of ElectricApparentPower from a value in microvoltamperes.

        

        :param meters: The ElectricApparentPower value in microvoltamperes.
        :type microvoltamperes: float
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower(microvoltamperes, ElectricApparentPowerUnits.Microvoltampere)

    
    @staticmethod
    def from_millivoltamperes(millivoltamperes: float):
        """
        Create a new instance of ElectricApparentPower from a value in millivoltamperes.

        

        :param meters: The ElectricApparentPower value in millivoltamperes.
        :type millivoltamperes: float
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower(millivoltamperes, ElectricApparentPowerUnits.Millivoltampere)

    
    @staticmethod
    def from_kilovoltamperes(kilovoltamperes: float):
        """
        Create a new instance of ElectricApparentPower from a value in kilovoltamperes.

        

        :param meters: The ElectricApparentPower value in kilovoltamperes.
        :type kilovoltamperes: float
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower(kilovoltamperes, ElectricApparentPowerUnits.Kilovoltampere)

    
    @staticmethod
    def from_megavoltamperes(megavoltamperes: float):
        """
        Create a new instance of ElectricApparentPower from a value in megavoltamperes.

        

        :param meters: The ElectricApparentPower value in megavoltamperes.
        :type megavoltamperes: float
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower(megavoltamperes, ElectricApparentPowerUnits.Megavoltampere)

    
    @staticmethod
    def from_gigavoltamperes(gigavoltamperes: float):
        """
        Create a new instance of ElectricApparentPower from a value in gigavoltamperes.

        

        :param meters: The ElectricApparentPower value in gigavoltamperes.
        :type gigavoltamperes: float
        :return: A new instance of ElectricApparentPower.
        :rtype: ElectricApparentPower
        """
        return ElectricApparentPower(gigavoltamperes, ElectricApparentPowerUnits.Gigavoltampere)

    
    @property
    def voltamperes(self) -> float:
        """
        
        """
        if self.__voltamperes != None:
            return self.__voltamperes
        self.__voltamperes = self.__convert_from_base(ElectricApparentPowerUnits.Voltampere)
        return self.__voltamperes

    
    @property
    def microvoltamperes(self) -> float:
        """
        
        """
        if self.__microvoltamperes != None:
            return self.__microvoltamperes
        self.__microvoltamperes = self.__convert_from_base(ElectricApparentPowerUnits.Microvoltampere)
        return self.__microvoltamperes

    
    @property
    def millivoltamperes(self) -> float:
        """
        
        """
        if self.__millivoltamperes != None:
            return self.__millivoltamperes
        self.__millivoltamperes = self.__convert_from_base(ElectricApparentPowerUnits.Millivoltampere)
        return self.__millivoltamperes

    
    @property
    def kilovoltamperes(self) -> float:
        """
        
        """
        if self.__kilovoltamperes != None:
            return self.__kilovoltamperes
        self.__kilovoltamperes = self.__convert_from_base(ElectricApparentPowerUnits.Kilovoltampere)
        return self.__kilovoltamperes

    
    @property
    def megavoltamperes(self) -> float:
        """
        
        """
        if self.__megavoltamperes != None:
            return self.__megavoltamperes
        self.__megavoltamperes = self.__convert_from_base(ElectricApparentPowerUnits.Megavoltampere)
        return self.__megavoltamperes

    
    @property
    def gigavoltamperes(self) -> float:
        """
        
        """
        if self.__gigavoltamperes != None:
            return self.__gigavoltamperes
        self.__gigavoltamperes = self.__convert_from_base(ElectricApparentPowerUnits.Gigavoltampere)
        return self.__gigavoltamperes

    
    def to_string(self, unit: ElectricApparentPowerUnits = ElectricApparentPowerUnits.Voltampere, fractional_digits: int = None) -> str:
        """
        Format the ElectricApparentPower to a string.
        
        Note: the default format for ElectricApparentPower is Voltampere.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the ElectricApparentPower. Default is 'Voltampere'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == ElectricApparentPowerUnits.Voltampere:
            return f"""{super()._truncate_fraction_digits(self.voltamperes, fractional_digits)} VA"""
        
        if unit == ElectricApparentPowerUnits.Microvoltampere:
            return f"""{super()._truncate_fraction_digits(self.microvoltamperes, fractional_digits)} μVA"""
        
        if unit == ElectricApparentPowerUnits.Millivoltampere:
            return f"""{super()._truncate_fraction_digits(self.millivoltamperes, fractional_digits)} mVA"""
        
        if unit == ElectricApparentPowerUnits.Kilovoltampere:
            return f"""{super()._truncate_fraction_digits(self.kilovoltamperes, fractional_digits)} kVA"""
        
        if unit == ElectricApparentPowerUnits.Megavoltampere:
            return f"""{super()._truncate_fraction_digits(self.megavoltamperes, fractional_digits)} MVA"""
        
        if unit == ElectricApparentPowerUnits.Gigavoltampere:
            return f"""{super()._truncate_fraction_digits(self.gigavoltamperes, fractional_digits)} GVA"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricApparentPowerUnits = ElectricApparentPowerUnits.Voltampere) -> str:
        """
        Get ElectricApparentPower unit abbreviation.
        Note! the default abbreviation for ElectricApparentPower is Voltampere.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricApparentPowerUnits.Voltampere:
            return """VA"""
        
        if unit_abbreviation == ElectricApparentPowerUnits.Microvoltampere:
            return """μVA"""
        
        if unit_abbreviation == ElectricApparentPowerUnits.Millivoltampere:
            return """mVA"""
        
        if unit_abbreviation == ElectricApparentPowerUnits.Kilovoltampere:
            return """kVA"""
        
        if unit_abbreviation == ElectricApparentPowerUnits.Megavoltampere:
            return """MVA"""
        
        if unit_abbreviation == ElectricApparentPowerUnits.Gigavoltampere:
            return """GVA"""
        